@@ -1,21 +1,9 @@
 /*
- * Copyright © 2016 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2016 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2016 Jan Grulich <jgrulich@redhat.com>
  */
 
 #ifndef XDG_DESKTOP_PORTAL_KDE_PRINT_H
@@ -51,12 +39,12 @@ public Q_SLOTS:
                       const QVariantMap &page_setup,
                       const QVariantMap &options,
                       QVariantMap &results);
+
 private:
-    QMap<uint, QPrinter*> m_printers;
+    QMap<uint, QPrinter *> m_printers;
 
     bool cupsAvailable();
-    QStringList printArguments(const QPrinter *printer, bool useCupsOptions, const QString &version,
-                               QPrinter::Orientation documentOrientation);
+    QStringList printArguments(const QPrinter *printer, bool useCupsOptions, const QString &version, QPrinter::Orientation documentOrientation);
     QStringList destination(const QPrinter *printer, const QString &version);
     QStringList copies(const QPrinter *printer, const QString &version);
     QStringList jobname(const QPrinter *printer, const QString &version);
@@ -73,4 +61,3 @@ private:
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_PRINT_H
-
